package com.diagbot.facade;

import com.diagbot.dto.GetQcClickDTO;
import com.diagbot.service.impl.MedClickInfoServiceImpl;
import com.diagbot.util.ListUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.util.SysUserUtils;
import com.diagbot.vo.GetQcClickVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;
import java.util.List;


/**
 * @Description:数据分析
 * @Author: cy
 * @time: 2021/11/16 18:28
 */
@Component
public class DataAnalysisFacade {
    @Autowired
    @Qualifier("medClickInfoServiceImpl")
    private MedClickInfoServiceImpl medClickInfoService;

    public List<GetQcClickDTO> getQcClick(GetQcClickVO getQcClickVO) {
        getQcClickVO.setHospitalId(Long.valueOf(SysUserUtils.getCurrentHospitalID()));
        List<GetQcClickDTO> records = medClickInfoService.getBaseMapper().getQcClick(getQcClickVO);
        //没有科室过滤时增加全院数据
        if (StringUtil.isBlank(getQcClickVO.getDeptName()) || getQcClickVO.getDeptName().equals("全院")) {
            GetQcClickDTO item = getGlobleTitle(records);
            if (item != null) {
                records.add(0, item);
            }
        }
        return records;
    }

    /**
     * 增加全院记录
     *
     * @param records
     * @return
     */
    public GetQcClickDTO getGlobleTitle(List<GetQcClickDTO> records) {
        GetQcClickDTO item = new GetQcClickDTO();
        if (ListUtil.isEmpty(records)) {
            return null;
        }

        //缺陷总数
        Integer clickTol = records
                .stream()
                .map(GetQcClickDTO::getClickNum)
                .reduce(0, Integer::sum);
        if (clickTol == null) {
            clickTol = 0;
        }
        item.setDeptName("全院");
        item.setClickNum(clickTol);
        return item;
    }
}
